<?php

namespace FiloBlu\MappConnectorExtension\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;

/**
 * Class MappAdditionalData
 * @package FiloBlu\Newsletter\Observer
 */
class MappAdditionalData implements ObserverInterface
{
    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $logger;

    /**
     * @var \FiloBlu\Newsletter\Model\SubscriberInfoFactory
     */
    protected $subscriberInfoFactory;

    /**
     * @var \FiloBlu\MappConnector\Model\Config
     */
    protected $config;

    /**
     * MappAdditionalData constructor.
     * @param \FiloBlu\Newsletter\Model\SubscriberInfoFactory $subscriberInfoFactory
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(
        \FiloBlu\Newsletter\Model\SubscriberInfoFactory $subscriberInfoFactory,
        \Psr\Log\LoggerInterface $logger,
        \FiloBlu\MappConnector\Model\Config $config
    )
    {
        $this->subscriberInfoFactory = $subscriberInfoFactory;
        $this->logger = $logger;
        $this->config = $config;
    }

    /**
     * @param Observer $observer
     * @return void
     */
    public function execute(Observer $observer)
    {
        try {
            $subscriber_object = $observer->getResult();
            $result = $subscriber_object->getSubscriberData();
            $subinfo = $this->subscriberInfoFactory->create();

            $nl_additional_data = [
                'subscriber_id' => '',
                'firstname' => '',
                'lastname' => '',
                'dob' => '',
                'country' => '',
                'gender' => '',
                'collections' => '',
                'source' => '',
                'language' => '',
                'website_name' => '',
                'birthday' => '',
                'phone' => '',
                'created_at' => '',
                'updated_at' => ''
            ];

            $newsletter_additional_data = $subinfo->load($result['subscriberid']);

            if (count($newsletter_additional_data->getData()) > 0) {
                $nl_additional_data = $newsletter_additional_data->getData();

                if (!empty($nl_additional_data['dob'])) {
                    $nl_additional_data['dob'] = date('Y-m-d', strtotime($nl_additional_data['dob'] . ' 00:00:00'));
                }

                //Get mapped gender
                $nl_additional_data['gender'] = $this->config->getNormalizedGender($nl_additional_data['gender']);

                $lan = explode('_', $nl_additional_data['language']);
                $nl_additional_data['language'] = $lan[0];
            }

            $result = array_merge($result, $nl_additional_data);

            unset(
                $result['subscriber_id'],
                $result['subscriberid']
            );

            $subscriber_object->setSubscriberData($result);
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
        }

    }

}